@@ -1,15 +1,16 @@
-from .const import DoorStatus, LockState, LockStatus
+from .const import DoorStatus, LockInfo, LockState, LockStatus
 from .lock import Lock
 from .push import PushLock
 from .session import AuthError
 from .util import local_name_to_serial, serial_to_local_name
 
-__version__ = "0.7.1"
+__version__ = "0.9.3"
 
 __all__ = [
     "AuthError",
     "Lock",
     "DoorStatus",
+    "LockInfo",
     "LockState",
     "LockStatus",
     "PushLock",
