@@ -15,6 +15,7 @@ from .const import (
     HAP_FIRST_BYTE,
     YALE_MFR_ID,
     DoorStatus,
+    LockInfo,
     LockState,
     LockStatus,
 )
@@ -93,6 +94,7 @@ class PushLock:
     def __init__(self, local_name: str) -> None:
         """Init the lock watcher."""
         self._local_name = local_name
+        self._lock_info: LockInfo | None = None
         self._lock_state: LockState | None = None
         self._last_adv_value = -1
         self._last_hk_state = -1
@@ -101,7 +103,7 @@ class PushLock:
         self._ble_device: BLEDevice | None = None
         self._operation_lock = asyncio.Lock()
         self._running = False
-        self._callbacks: list[Callable[[LockState], None]] = []
+        self._callbacks: list[Callable[[LockState, LockInfo], None]] = []
         self._update_task: asyncio.Task | None = None  # type: ignore[type-arg]
         self._debounce_lock = asyncio.Lock()
         self.loop = asyncio._get_running_loop()
@@ -132,8 +134,13 @@ class PushLock:
         """Return the current lock state."""
         return self._lock_state
 
+    @property
+    def lock_info(self) -> LockInfo | None:
+        """Return the current lock info."""
+        return self._lock_info
+
     def register_callback(
-        self, callback: Callable[[LockState], None]
+        self, callback: Callable[[LockState, LockInfo], None]
     ) -> Callable[[], None]:
         """Register a callback to be called when the lock state changes."""
 
@@ -180,13 +187,11 @@ class PushLock:
         self._callback_state(LockState(LockStatus.LOCKING, self.door_status))
         lock = self._get_lock_instance()
         try:
-            await lock.connect()
-            await lock.force_lock()
+            async with lock:
+                await lock.force_lock()
         except Exception:
             self._callback_state(LockState(LockStatus.UNKNOWN, self.door_status))
             raise
-        finally:
-            await lock.disconnect()
         self._callback_state(LockState(LockStatus.LOCKED, self.door_status))
         await self._cancel_any_update()
         _LOGGER.debug("Finished lock")
@@ -200,13 +205,11 @@ class PushLock:
         self._callback_state(LockState(LockStatus.UNLOCKING, self.door_status))
         lock = self._get_lock_instance()
         try:
-            await lock.connect()
-            await lock.force_unlock()
+            async with lock:
+                await lock.force_unlock()
         except Exception:
             self._callback_state(LockState(LockStatus.UNKNOWN, self.door_status))
             raise
-        finally:
-            await lock.disconnect()
         self._callback_state(LockState(LockStatus.UNLOCKED, self.door_status))
         await self._cancel_any_update()
         _LOGGER.debug("Finished unlock")
@@ -217,26 +220,27 @@ class PushLock:
         """Update the lock state."""
         lock = self._get_lock_instance()
         try:
-            await lock.connect()
-            state = await lock.status()
+            async with lock:
+                if not self._lock_info:
+                    self._lock_info = await lock.lock_info()
+                state = await lock.status()
         except asyncio.CancelledError:
             _LOGGER.debug(
                 "%s: In-progress update canceled due to lock operation", self.name
             )
             raise
-        finally:
-            await lock.disconnect()
         _LOGGER.debug("%s: Updating lock state", self.name)
         self._callback_state(state)
         return state
 
     def _callback_state(self, lock_state: LockState) -> None:
         """Call the callbacks."""
+        assert self._lock_info is not None  # nosec
         self._lock_state = lock_state
         _LOGGER.debug("%s: New lock state: %s", self.name, self._lock_state)
         for callback in self._callbacks:
             try:
-                callback(lock_state)
+                callback(lock_state, self._lock_info)
             except Exception:  # pylint: disable=broad-except
                 _LOGGER.exception("%s: Error calling callback", self.name)
 
@@ -253,7 +257,7 @@ class PushLock:
             ad,
         )
         self.set_ble_device(ble_device)
-        has_update = 0
+        next_update = 0
         mfr_data = dict(ad.manufacturer_data)
         if APPLE_MFR_ID in mfr_data and mfr_data[APPLE_MFR_ID][0] == HAP_FIRST_BYTE:
             hk_state = get_homekit_state_num(mfr_data[APPLE_MFR_ID])
@@ -263,24 +267,32 @@ class PushLock:
             # if len(mfr_data[APPLE_MFR_ID]) > 20 and YALE_MFR_ID not in mfr_data:
             # mfr_data[YALE_MFR_ID] = mfr_data[APPLE_MFR_ID][20:]
             if hk_state != self._last_hk_state:
-                has_update = HK_UPDATE_COALESCE_SECONDS
+                next_update = HK_UPDATE_COALESCE_SECONDS
                 self._last_hk_state = hk_state
         if YALE_MFR_ID in mfr_data:
             current_value = mfr_data[YALE_MFR_ID][0]
             if current_value != self._last_adv_value:
-                has_update = ADV_UPDATE_COALESCE_SECONDS
+                if not next_update:
+                    next_update = ADV_UPDATE_COALESCE_SECONDS
                 self._last_adv_value = current_value
-        _LOGGER.debug(
-            "%s: State: (current_state: %s) (hk_state: %s) "
-            "(adv_value: %s) (has_update: %s)",
-            self.name,
-            self._lock_state,
-            self._last_hk_state,
-            self._last_adv_value,
-            has_update,
-        )
-        if has_update:
-            self._schedule_update(has_update)
+        if _LOGGER.isEnabledFor(logging.DEBUG):
+            scheduled_update = None
+            if self._cancel_deferred_update:
+                scheduled_update = (
+                    self._cancel_deferred_update.when() - self.loop.time()
+                )
+            _LOGGER.debug(
+                "%s: State: (current_state: %s) (hk_state: %s) "
+                "(adv_value: %s) (next_update: %s) (scheduled_update: %s)",
+                self.name,
+                self._lock_state,
+                self._last_hk_state,
+                self._last_adv_value,
+                next_update,
+                scheduled_update,
+            )
+        if next_update:
+            self._schedule_update(next_update)
 
     async def start(self) -> Callable[[], None]:
         """Start watching for updates."""
@@ -301,7 +313,7 @@ class PushLock:
         future_update_time = seconds
         if self._cancel_deferred_update:
             time_till_update = self._cancel_deferred_update.when() - now
-            if future_update_time < HK_UPDATE_COALESCE_SECONDS:
+            if time_till_update < HK_UPDATE_COALESCE_SECONDS:
                 future_update_time = HK_UPDATE_COALESCE_SECONDS
                 _LOGGER.debug(
                     "%s: Existing update too soon %s, "
@@ -331,13 +343,13 @@ class PushLock:
 
     def _deferred_update(self) -> None:
         """Update the lock state."""
+        self._cancel_deferred_update = None
         if self._debounce_lock.locked():
             _LOGGER.debug(
                 "%s: Rescheduling update since one already in progress", self.name
             )
             self._schedule_update(UPDATE_IN_PROGRESS_DEFER_SECONDS)
             return
-        self._cancel_deferred_update = None
         self.loop.create_task(self.update())
 
     async def _queue_update(self) -> None:
